Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3369)

Unified Diff: base/files/file_path_watcher_fsevents.h

Issue 2123333003: Remove base::mac::LibDispatchTaskRunner and migrate its sole client to plain libdispatch. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Tweak comments Created 4 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: base/files/file_path_watcher_fsevents.h
diff --git a/base/files/file_path_watcher_fsevents.h b/base/files/file_path_watcher_fsevents.h
index 1ebe4636e4ba19bfa58bc2eec84320ecd1720365..cfbe020b512cb26c4ab72d89a65d39e0f3d06660 100644
--- a/base/files/file_path_watcher_fsevents.h
+++ b/base/files/file_path_watcher_fsevents.h
@@ -12,6 +12,7 @@
#include "base/files/file_path.h"
#include "base/files/file_path_watcher.h"
+#include "base/mac/scoped_dispatch_object.h"
#include "base/macros.h"
namespace base {
@@ -76,16 +77,19 @@ class FilePathWatcherFSEvents : public FilePathWatcher::PlatformDelegate {
// (Only accessed from the message_loop() thread.)
FilePathWatcher::Callback callback_;
+ // The dispatch queue on which the the event stream is scheduled.
+ ScopedDispatchObject<dispatch_queue_t> queue_;
+
// Target path to watch (passed to callback).
// (Only accessed from the libdispatch thread.)
FilePath target_;
// Target path with all symbolic links resolved.
// (Only accessed from the libdispatch thread.)
FilePath resolved_target_;
// Backend stream we receive event callbacks from (strong reference).
// (Only accessed from the libdispatch thread.)
FSEventStreamRef fsevent_stream_;
DISALLOW_COPY_AND_ASSIGN(FilePathWatcherFSEvents);
@@ -76,16 +77,19 @@ class FilePathWatcherFSEvents : public FilePathWatcher::PlatformDelegate {
// Target path to watch (passed to callback).
- // (Only accessed from the libdispatch thread.)
+ // (Only accessed from the libdispatch queue.)
FilePath target_;
// Target path with all symbolic links resolved.
@@ -76,16 +77,19 @@ class FilePathWatcherFSEvents : public FilePathWatcher::PlatformDelegate {
FilePath target_;
// Target path with all symbolic links resolved.
- // (Only accessed from the libdispatch thread.)
+ // (Only accessed from the libdispatch queue.)
FilePath resolved_target_;
// Backend stream we receive event callbacks from (strong reference).
@@ -76,16 +77,19 @@ class FilePathWatcherFSEvents : public FilePathWatcher::PlatformDelegate {
FilePath resolved_target_;
// Backend stream we receive event callbacks from (strong reference).
- // (Only accessed from the libdispatch thread.)
+ // (Only accessed from the libdispatch queue.)
FSEventStreamRef fsevent_stream_;
DISALLOW_COPY_AND_ASSIGN(FilePathWatcherFSEvents);

Powered by Google App Engine
This is Rietveld 408576698